Structs
- Rich
- A rich default error type that tracks error spans, expected inputs, and the actual input found at an error site.
Functions
- format_
error_ simple - Simple error formatting without Ariadne (for tests and simple output)
- format_
parse_ errors - Format parse errors as a string without printing
- print_
parse_ errors - Pretty-print parse errors using Ariadne