pub struct Rich<'a, T, S = SimpleSpan> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a, T, S> Rich<'a, T, S>
impl<'a, T, S> Rich<'a, T, S>
Sourcepub fn custom<M>(span: S, msg: M) -> Rich<'a, T, S>where
M: ToString,
pub fn custom<M>(span: S, msg: M) -> Rich<'a, T, S>where
M: ToString,
Create an error with a custom message and span
Sourcepub fn reason(&self) -> &RichReason<'a, T>
pub fn reason(&self) -> &RichReason<'a, T>
Get the reason for this error.
Sourcepub fn into_reason(self) -> RichReason<'a, T>
pub fn into_reason(self) -> RichReason<'a, T>
Take the reason from this error.
Sourcepub fn found(&self) -> Option<&T>
pub fn found(&self) -> Option<&T>
Get the token found by this error when parsing. None implies that the error expected the end of input.
Sourcepub fn contexts(&self) -> impl Iterator<Item = (&RichPattern<'a, T>, &S)>
pub fn contexts(&self) -> impl Iterator<Item = (&RichPattern<'a, T>, &S)>
Return an iterator over the labelled contexts of this error, from least general to most.
‘Context’ here means parser patterns that the parser was in the process of parsing when the error occurred. To
add labelled contexts, see Parser::labelled.
Sourcepub fn into_owned<'b>(self) -> Rich<'b, T, S>where
T: Clone,
pub fn into_owned<'b>(self) -> Rich<'b, T, S>where
T: Clone,
Convert this error into an owned version of itself by cloning any borrowed internal tokens, if necessary.
Sourcepub fn expected(&self) -> impl ExactSizeIterator
pub fn expected(&self) -> impl ExactSizeIterator
Get an iterator over the expected items associated with this error