Module error

Module error 

Structs

Rich
A rich default error type that tracks error spans, expected inputs, and the actual input found at an error site.

Functions

format_error_simple
Simple error formatting without Ariadne (for tests and simple output)
format_parse_errors
Format parse errors as a string without printing
print_parse_errors
Pretty-print parse errors using Ariadne