Rich

Struct Rich 

pub struct Rich<'a, T, S = SimpleSpan> { /* private fields */ }
A rich default error type that tracks error spans, expected inputs, and the actual input found at an error site.

Please note that it uses a Vec to remember expected symbols. If you find this to be too slow, you can implement Error for your own error type or use Simple instead.

Implementations

Source

impl<'a, T, S> Rich<'a, T, S>

pub fn custom<M>(span: S, msg: M) -> Rich<'a, T, S>
where M: ToString,

Create an error with a custom message and span

pub fn span(&self) -> &S

Get the span associated with this error.

pub fn reason(&self) -> &RichReason<'a, T>

Get the reason for this error.

pub fn into_reason(self) -> RichReason<'a, T>

Take the reason from this error.

pub fn found(&self) -> Option<&T>

Get the token found by this error when parsing. None implies that the error expected the end of input.

pub fn contexts(&self) -> impl Iterator<Item = (&RichPattern<'a, T>, &S)>

Return an iterator over the labelled contexts of this error, from least general to most.

‘Context’ here means parser patterns that the parser was in the process of parsing when the error occurred. To add labelled contexts, see Parser::labelled.

pub fn into_owned<'b>(self) -> Rich<'b, T, S>
where T: Clone,

Convert this error into an owned version of itself by cloning any borrowed internal tokens, if necessary.

pub fn expected(&self) -> impl ExactSizeIterator

Get an iterator over the expected items associated with this error

pub fn map_token<U, F>(self, f: F) -> Rich<'a, U, S>
where F: FnMut(T) -> U, T: Clone,

Transform this error’s tokens using the given function.

This is useful when you wish to combine errors from multiple compilation passes (lexing and parsing, say) where the token type for each pass is different (char vs MyToken, say).